@@ -1,9 +1,7 @@
 """Python implementation of MySensors API."""
 import logging
 
-# pylint: disable=no-name-in-module, import-error
 from distutils.version import LooseVersion as parse_ver
-from functools import partial
 from pathlib import Path
 
 import voluptuous as vol
@@ -16,7 +14,7 @@ from .task import AsyncTasks, SyncTasks
 from .validation import safe_is_version
 
 _LOGGER = logging.getLogger(__name__)
-__version__ = (Path(__file__).parent / "VERSION").read_text().strip()
+__version__ = (Path(__file__).parent / "VERSION").read_text(encoding="utf-8").strip()
 
 
 class Gateway:
@@ -42,7 +40,7 @@ class Gateway:
 
     def __repr__(self):
         """Return the representation."""
-        return "<{}>".format(self.__class__.__name__)
+        return f"<{self.__class__.__name__}>"
 
     def logic(self, data):
         """Parse the data and respond to it appropriately.
@@ -64,9 +62,9 @@ class Gateway:
         msg.gateway = self
         message_type = self.const.MessageType(msg.type)
         handler = message_type.get_handler(self.handlers)
-        msg = handler(msg)
-        msg = self._route_message(msg)
-        return msg.encode() if msg else None
+        reply = handler(msg)
+        reply = self._route_message(reply)
+        return reply.encode() if reply else None
 
     def alert(self, msg):
         """Tell anyone who wants to know that a sensor was updated."""
@@ -97,6 +95,41 @@ class Gateway:
             self.sensors[sensorid] = Sensor(sensorid)
         return sensorid if sensorid in self.sensors else None
 
+    def create_message_to_set_sensor_value(
+        self, sensor, child_id, value_type, value, **kwargs
+    ):
+        """Create a message to set specified sensor child value."""
+        msg_type = kwargs.get("msg_type", self.const.MessageType.set)
+        ack = kwargs.get("ack", 0)
+
+        try:
+            value_type = int(value_type)
+        except (ValueError, TypeError) as exc:
+            raise ValueError(f"Invalid value_type provided: {value_type}") from exc
+
+        value = str(value)
+
+        msg = Message(
+            node_id=sensor.sensor_id,
+            child_id=child_id,
+            type=msg_type,
+            ack=ack,
+            sub_type=value_type,
+            payload=value,
+        )
+
+        msg_string = msg.encode()
+
+        if msg_string is None:
+            raise ValueError(
+                f"Unable to encode message: node {sensor.sensor_id}, child {child_id}, "
+                "type {msg_type}, ack {ack}, sub_type {value_type}, payload {value}"
+            )
+
+        msg.validate(self.protocol_version)
+
+        return msg
+
     def is_sensor(self, sensorid, child_id=None):
         """Return True if a sensor and its child exist."""
         ret = sensorid in self.sensors
@@ -124,13 +157,16 @@ class Gateway:
             or msg.type == self.const.MessageType.presentation
         ):
             return None
+
         if (
             msg.node_id not in self.sensors
             or msg.type == self.const.MessageType.stream
-            or not self.sensors[msg.node_id].new_state
+            or not self.sensors[msg.node_id].is_smart_sleep_node
         ):
             return msg
+
         self.sensors[msg.node_id].queue.append(msg.encode())
+
         return None
 
     def set_child_value(self, sensor_id, child_id, value_type, value, **kwargs):
@@ -146,25 +182,41 @@ class Gateway:
         """
         if not self.is_sensor(sensor_id, child_id):
             return
-        if self.sensors[sensor_id].new_state:
-            self.sensors[sensor_id].set_child_value(
-                child_id, value_type, value, children=self.sensors[sensor_id].new_state
-            )
-        else:
-            self.tasks.add_job(
-                partial(
-                    self.sensors[sensor_id].set_child_value,
-                    child_id,
-                    value_type,
-                    value,
-                    **kwargs
-                )
-            )
+
+        sensor = self.sensors[sensor_id]
+
+        if sensor.is_smart_sleep_node:
+            sensor.set_child_desired_state(child_id, value_type, value)
+            return
+
+        msg_to_send = self.create_message_to_set_sensor_value(
+            sensor, child_id, value_type, value, **kwargs
+        )
+
+        self.tasks.add_job(msg_to_send.encode)
 
     def send(self, message):
         """Write a message to the arduino gateway."""
         self.tasks.transport.send(message)
 
+
+class BaseSyncGateway(Gateway):
+    """MySensors base sync gateway."""
+
+    def __init__(
+        self,
+        transport,
+        *args,
+        persistence=False,
+        persistence_file="mysensors.pickle",
+        **kwargs,
+    ):
+        """Set up gateway."""
+        super().__init__(*args, **kwargs)
+        self.tasks = SyncTasks(
+            self.const, persistence, persistence_file, self.sensors, transport
+        )
+
     def start(self):
         """Start the gateway and task allow tasks to be scheduled."""
         self.tasks.start()
@@ -178,28 +230,10 @@ class Gateway:
         self.tasks.start_persistence()
 
     def update_fw(self, nids, fw_type, fw_ver, fw_path=None):
-        """Update firwmare of all node_ids in nids."""
+        """Update firmware of all node_ids in nids."""
         self.tasks.update_fw(nids, fw_type, fw_ver, fw_path=fw_path)
 
 
-class BaseSyncGateway(Gateway):
-    """MySensors base sync gateway."""
-
-    def __init__(
-        self,
-        transport,
-        *args,
-        persistence=False,
-        persistence_file="mysensors.pickle",
-        **kwargs
-    ):
-        """Set up gateway."""
-        super().__init__(*args, **kwargs)
-        self.tasks = SyncTasks(
-            self.const, persistence, persistence_file, self.sensors, transport
-        )
-
-
 class BaseAsyncGateway(Gateway):
     """MySensors base async gateway."""
 
@@ -210,7 +244,7 @@ class BaseAsyncGateway(Gateway):
         loop=None,
         persistence=False,
         persistence_file="mysensors.pickle",
-        **kwargs
+        **kwargs,
     ):
         """Set up gateway."""
         super().__init__(*args, **kwargs)
@@ -236,5 +270,5 @@ class BaseAsyncGateway(Gateway):
         await self.tasks.start_persistence()
 
     async def update_fw(self, nids, fw_type, fw_ver, fw_path=None):
-        """Update firwmare of all node_ids in nids."""
+        """Update firmware of all node_ids in nids."""
         await self.tasks.update_fw(nids, fw_type, fw_ver, fw_path=fw_path)
