@@ -2,22 +2,31 @@
 import click
 
 from mysensors.cli.helper import (
-    common_gateway_options, handle_msg, run_async_gateway, run_gateway)
+    common_gateway_options,
+    handle_msg,
+    run_async_gateway,
+    run_gateway,
+)
 from mysensors.gateway_tcp import AsyncTCPGateway, TCPGateway
 
 
 def common_tcp_options(func):
     """Supply common tcp gateway options."""
     func = click.option(
-        '-p', '--port', default=5003, show_default=True, type=int,
-        help='TCP port of the connection.')(func)
+        "-p",
+        "--port",
+        default=5003,
+        show_default=True,
+        type=int,
+        help="TCP port of the connection.",
+    )(func)
     func = click.option(
-        '-H', '--host', required=True, help='TCP address of the gateway.'
+        "-H", "--host", required=True, help="TCP address of the gateway."
     )(func)
     return func
 
 
-@click.command(options_metavar='<options>')
+@click.command(options_metavar="<options>")
 @common_tcp_options
 @common_gateway_options
 def tcp_gateway(**kwargs):
@@ -26,7 +35,7 @@ def tcp_gateway(**kwargs):
     run_gateway(gateway)
 
 
-@click.command(options_metavar='<options>')
+@click.command(options_metavar="<options>")
 @common_tcp_options
 @common_gateway_options
 def async_tcp_gateway(**kwargs):
