@@ -10,17 +10,21 @@ _LOGGER = logging.getLogger(__name__)
 def common_gateway_options(func):
     """Supply common gateway options."""
     func = click.option(
-        '-v', '--protocol_version', help='Protocol version of the gateway.',
-        default='2.2', show_default=True)(func)
+        "-v",
+        "--protocol_version",
+        help="Protocol version of the gateway.",
+        default="2.2",
+        show_default=True,
+    )(func)
     func = click.option(
-        '-s', '--persistence', help='Turn on persistence.',
-        is_flag=True)(func)
+        "-s", "--persistence", help="Turn on persistence.", is_flag=True
+    )(func)
     return func
 
 
 def handle_msg(msg):
     """Handle mysensors updates."""
-    _LOGGER.info('Received message: %s', msg.encode().strip())
+    _LOGGER.info("Received message: %s", msg.encode().strip())
 
 
 def run_gateway(gateway):
