@@ -17,7 +17,7 @@ class Persistence:
         self._sensors = sensors
         self.need_save = True
         self.persistence_file = persistence_file
-        self.persistence_bak = "{}.bak".format(self.persistence_file)
+        self.persistence_bak = f"{self.persistence_file}.bak"
         self.schedule_save_sensors = schedule_factory(self.save_sensors)
 
     def _save_pickle(self, filename):
@@ -34,14 +34,14 @@ class Persistence:
 
     def _save_json(self, filename):
         """Save sensors to json file."""
-        with open(filename, "w") as file_handle:
+        with open(filename, "w", encoding="utf-8") as file_handle:
             json.dump(self._sensors, file_handle, cls=MySensorsJSONEncoder, indent=4)
             file_handle.flush()
             os.fsync(file_handle.fileno())
 
     def _load_json(self, filename):
         """Load sensors from json file."""
-        with open(filename, "r") as file_handle:
+        with open(filename, "r", encoding="utf-8") as file_handle:
             self._sensors.update(json.load(file_handle, cls=MySensorsJSONDecoder))
 
     def save_sensors(self):
@@ -55,7 +55,7 @@ class Persistence:
             _LOGGER.error("Permission denied when writing to %s", fname)
             return
         split_fname = os.path.splitext(fname)
-        tmp_fname = "{}.tmp{}".format(split_fname[0], split_fname[1])
+        tmp_fname = f"{split_fname[0]}.tmp{split_fname[1]}"
         _LOGGER.debug("Saving sensors to persistence file %s", fname)
         self._perform_file_action(tmp_fname, "save")
         if exists:
@@ -107,37 +107,36 @@ class Persistence:
         """
         ext = os.path.splitext(filename)[1]
         try:
-            func = getattr(self, "_{}_{}".format(action, ext[1:]))
-        except AttributeError:
-            raise Exception("Unsupported file type {}".format(ext[1:]))
+            func = getattr(self, f"_{action}_{ext[1:]}")
+        except AttributeError as exc:
+            raise Exception(f"Unsupported file type {ext[1:]}") from exc
         func(filename)
 
 
 class MySensorsJSONEncoder(json.JSONEncoder):
     """JSON encoder."""
 
-    def default(self, obj):
+    def default(self, o):
         """Serialize obj into JSON."""
-        # pylint: disable=method-hidden, protected-access, arguments-differ
-        if isinstance(obj, Sensor):
+        if isinstance(o, Sensor):
             return {
-                "sensor_id": obj.sensor_id,
-                "children": obj.children,
-                "type": obj.type,
-                "sketch_name": obj.sketch_name,
-                "sketch_version": obj.sketch_version,
-                "battery_level": obj.battery_level,
-                "protocol_version": obj.protocol_version,
-                "heartbeat": obj.heartbeat,
+                "sensor_id": o.sensor_id,
+                "children": o.children,
+                "type": o.type,
+                "sketch_name": o.sketch_name,
+                "sketch_version": o.sketch_version,
+                "battery_level": o.battery_level,
+                "protocol_version": o.protocol_version,
+                "heartbeat": o.heartbeat,
             }
-        if isinstance(obj, ChildSensor):
+        if isinstance(o, ChildSensor):
             return {
-                "id": obj.id,
-                "type": obj.type,
-                "description": obj.description,
-                "values": obj.values,
+                "id": o.id,
+                "type": o.type,
+                "description": o.description,
+                "values": o.values,
             }
-        return json.JSONEncoder.default(self, obj)
+        return json.JSONEncoder.default(self, o)
 
 
 class MySensorsJSONDecoder(json.JSONDecoder):
