@@ -27,10 +27,6 @@ class Transport:
         self.reconnect_timeout = reconnect_timeout
         self.timeout = timeout
 
-    def connect(self):
-        """Connect to the transport."""
-        raise NotImplementedError
-
     def disconnect(self):
         """Disconnect from the transport."""
         if not self.protocol or not self.protocol.transport:
@@ -110,7 +106,7 @@ class BaseMySensorsProtocol(serial.threaded.LineReader):
 
     def __repr__(self):
         """Return the representation."""
-        return "<{}>".format(self.__class__.__name__)
+        return f"<{self.__class__.__name__}>"
 
     def connection_made(self, transport):
         """Handle created connection."""
