@@ -1,12 +1,9 @@
 """Expose validators to use in the library."""
-# pylint: disable=import-error, no-name-in-module
 from distutils.version import LooseVersion as parse_ver
 import logging
 
 import voluptuous as vol
 
-# pylint: disable=invalid-name
-
 _LOGGER = logging.getLogger(__name__)
 
 percent_int = vol.All(vol.Coerce(int), vol.Range(min=0, max=100))
@@ -19,8 +16,8 @@ def is_version(value):
         if parse_ver("1.4") > parse_ver(value):
             raise ValueError()
         return value
-    except (AttributeError, TypeError, ValueError):
-        raise vol.Invalid("{} is not a valid version specifier".format(value))
+    except (AttributeError, TypeError, ValueError) as exc:
+        raise vol.Invalid(f"{value} is not a valid version specifier") from exc
 
 
 def safe_is_version(value):
